# sunbi
尚德机构BI工程师常用包
## 包说明
- 网络部分
    - requests.get/post
    - selenium demo
- 数据库部分
    - 跑
    - 插
    - 关
- 表格部分
    - 刷新
    - 运行宏
    - 保存图片
- 邮件部分
    - 发邮件
    - 下载邮件附件
- 文件部分
    - 清空文件夹
    - 获取文件夹下的文件
    - FTP传输

<br>

## 业务场景说明
- 获取数据源
    - 邮件获取
    - FTP获取
    - API获取
    - 自行爬虫
    - 数据库传输
- 数据库处理
- 表格建模
- 分发
  - 企业微信机器人分发
  - 邮件分发
  - 跳过表格 直接数据库到分发
